@@ -33,6 +33,7 @@ class User:
                         installer = package_info_split[1].split("=")[1]
                         if installer_keyword in installer:
                             packages.append(package_id)
+                packages.remove("kshib.fdroid.cli")
             except subprocess.CalledProcessError as e:
                 print("Failed to check package version for", e.output)
         return packages
@@ -126,7 +127,7 @@ class Repo:
             if not os.path.exists(f"{self.dl_dir}/{repo}"):
                 os.makedirs(f"{self.dl_dir}/{repo}")
             download(f"{repo_url}/{os.path.basename(index_file)}", f"{self.dl_dir}/{repo}")
-            # for f-droid, index is in a jar, unzip it and clean up
+            # for some repos, index is in a jar, unzip it and clean up
             if ext == "jar":
                 with zipfile.ZipFile(f"{self.dl_dir}/{repo}/{os.path.basename(index_file)}", "r") as zf:
                     zf.extractall(f"{self.dl_dir}/{repo}/")
@@ -204,6 +205,7 @@ class Repo:
                     packages_list.extend(
                         {
                             "apkName": get(apk, "apkName"),
+                            "packageName": get(apk, "packageName"),
                             "versionName": get(apk, "versionName"),
                             "versionCode": get(apk, "versionCode"),
                             "size": get(apk, "size"),
@@ -269,10 +271,8 @@ class Repo:
         :return:
         """
         for package in self.packages(app):
-            if app == package:
-                for apk in self.data["packages"][app]:
-                    if apk["versionName"] == version_name:
-                        return apk["versionCode"]
+            if app == package["packageName"] and package["versionName"] == version_name:
+                return package["versionCode"]
 
     def subscribe(self, repo: str) -> None:
         """
@@ -344,7 +344,7 @@ class Installer:
             pbar.update(1)
         pbar.close()
 
-    def suggested_outdated(self, id_: str) -> int:
+    def suggested_outdated(self, id_: str) -> any:
         """
         Returns newer 'suggested' version if available, 0 otherwise
         :param id_: Package name
@@ -352,53 +352,42 @@ class Installer:
         """
         for r in self.repo.subscribed_repos():
             self.repo.quick_load(r)
-            if self.repo.suggested_package(id_, self.user) is not None:
-                version = self.repo.suggested_package(id_, self.user)["versionCode"]
-                return version if self.installed_package_version(id_) < version else 0
+            package = self.repo.suggested_package(id_, self.user)
+            if package is not None:
+                version = package["versionName"]
+                if self.installed_package_version(id_) < version:
+                    return version, self.repo.address(package["repo"]), package["apkName"]
+                else:
+                    return None
 
-    def latest_outdated(self, id_: str):
-        """
-        Returns newer 'latest' version if available, 0 otherwise
-        :param id_: Package name
-        :return: Newer 'latest' version if available, 0 otherwise
-        """
-        for r in self.repo.subscribed_repos():
-            self.repo.quick_load(r)
-            version = self.repo.latest_package(id_, self.user.cpu())
-            if self.installed_package_version(id_) < self.repo.latest_package(id_, self.user.cpu())["versionCode"]:
-                return version
-            return 0
-
-    def outdated_packages(self, suggested: bool = True) -> list:
+    def outdated_packages(self) -> list:
         """
         Returns list of outdated packages
-        :param suggested: Package versions. True=suggested, False=latest
         :return: List of outdated packages
         """
         packages = []
-        for package_id in self.user.installed_packages('fdroid.cli'):
-            if suggested:
-                if new_version := self.suggested_outdated(package_id):
-                    packages.append(f"https://f-droid.org/repo/{package_id}_{new_version}.apk")
-            if not suggested and self.latest_outdated(package_id):
-                if new_version := self.latest_outdated(package_id):
-                    packages.append(f"https://f-droid.org/repo/{package_id}_{new_version}.apk")
+        packages.extend(
+            f"{version[1]}/{version[2]}"
+            for package_id in self.user.installed_packages('kshib.fdroid.cli')
+            if (version := self.suggested_outdated(package_id))
+        )
+
         return packages
 
-    def installed_package_version(self, id_: str) -> int:
+    @staticmethod
+    def installed_package_version(id_: str) -> str:
         """
         Returns installed package version for package name
         :param id_: Package name
-        :return: Installed package version if found, 0 otherwise
+        :return: Installed package version if found, empty string otherwise
         """
         if adb_connected():
             try:
                 output = command(f"adb shell dumpsys package {id_} | grep versionName")
-                version_name = output.strip("\n").split("=")[1]
-                return self.repo.version_code(id_, version_name)
+                return output.strip("\n").split("=")[1]
             except subprocess.CalledProcessError as e:
                 print(f"Failed to check package version for '{id_}'", e.output)
-        return 0
+        return ""
 
     def apk_url(self, id_: str):
         """
@@ -409,7 +398,7 @@ class Installer:
         package = self.repo.suggested_package(id_, self.user)
         address = self.repo.address(package['repo'])
         if "/repo" not in address:
-            address = "".join([address, 'repo'])
+            address = "".join([address, '/repo'])
         return f"{address}/{package['apkName']}"
 
     def apk_urls(self, ids: list) -> list[str]:
@@ -427,13 +416,17 @@ class Installer:
         pbar.close()
         return __urls
 
-    def install_all(self, ids: list) -> None:
+    def install_all(self, ids=None, package_urls=None) -> None:
         """
         Installs app with given url
+        :param package_urls: List of package urls to install
         :param ids: List of package names to install
         :return:None
         """
-        package_urls = self.apk_urls(ids)
+        if ids is None:
+            ids = []
+        if not package_urls:
+            package_urls = self.apk_urls(ids)
         self.download_multiple(package_urls)
         if adb_connected():
             results = ThreadPool(4).imap_unordered(self.install, package_urls)
@@ -442,7 +435,8 @@ class Installer:
                     pbar.update(1)
             pbar.close()
 
-    def install(self, url: str) -> (str, bool):
+    @staticmethod
+    def install(url: str) -> (str, bool):
         """
         Installs app with given url
         :param url: APK file url
